<?php

define('OP_SMART_THEME_VERSION', '1.0.12');
define('OP_SMART_THEME_DIR', rtrim(get_template_directory(), '/').'/');

// Minified resources (script and style)
if (!defined('OP_SMART_DEBUG')) {
    define('OP_SMART_DEBUG', '.min');
}

/**
 * Loading Redux Framework and OP config
 */
if (!class_exists('ReduxFramework') && file_exists(dirname(__FILE__) . '/vendor/ReduxFramework/ReduxCore/framework.php')) {
    require_once(dirname(__FILE__) . '/vendor/ReduxFramework/ReduxCore/framework.php');
}
if (!isset($redux_demo) && file_exists(dirname(__FILE__) . '/options.php')) {
    require_once(dirname(__FILE__) . '/options.php');
}

/**
 * smart functions and definitions.
 *
 * @link https://codex.wordpress.org/Functions_File_Explained
 *
 * @package smart
 */

if (!function_exists('op_setup')) {
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     */
    function op_setup()
    {
        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         */
        load_theme_textdomain('optimizepress_smart', get_template_directory() . '/languages');

        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support('title-tag');

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support('post-thumbnails');

        add_image_size('related-article-size', 350, 195, true);

        add_image_size('homepage-grid-size', 383, 215, array( 'center', 'center'));
        add_image_size('homepage-list-size', 420, 260, array( 'center', 'center'));

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus(array(
            'primary' => esc_html_x('Header Menu', 'Menus', 'optimizepress_smart'),
        ));

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ));

        /*
         * Enable support for Post Formats.
         * See https://developer.wordpress.org/themes/functionality/post-formats/
         */
        add_theme_support('post-formats', array(
            // 'aside',
            // 'image',
            'audio',
            'video',
            // 'quote',
            // 'link',
            'gallery',
        ));

        // WooCommerce support
        add_theme_support('woocommerce');
        add_theme_support('wc-product-gallery-zoom');
        add_theme_support('wc-product-gallery-lightbox');
        add_theme_support('wc-product-gallery-slider');
    }
}
add_action('after_setup_theme', 'op_setup');

/**
 * Register widget area and widgets.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function op_widgets_init()
{
    register_sidebar(array(
        'name'          => _x('Sidebar', 'Widgets', 'optimizepress_smart'),
        'id'            => 'sidebar-1',
        'description'   => '',
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h2 class="widget-title">',
        'after_title'   => '</h2>',
    ));

    if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
        register_sidebar(array(
            'name'          => _x('Shop Sidebar', 'Widgets', 'optimizepress_smart'),
            'id'            => 'shop-archive',
            'description'   => '',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h2 class="widget-title">',
            'after_title'   => '</h2>',
        ));

        register_sidebar(array(
            'name'          => _x('Shop Product Details Sidebar', 'Widgets', 'optimizepress_smart'),
            'id'            => 'shop-single',
            'description'   => '',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h2 class="widget-title">',
            'after_title'   => '</h2>',
        ));
    }

    register_widget('Op_Social_Profiles_Widget');
    register_widget('Op_Optin_Form_Widget');
}
add_action('widgets_init', 'op_widgets_init');

/**
 * Enqueue scripts and styles.
 */
function op_scripts()
{
    // We don't want to load theme scripts
    // or styles on LiveEditor pages
    // or in LiveEditor
    if (is_op_page()) {
        return;
    }

    // CSS debug version
    if (OP_SMART_DEBUG === '') {

        wp_enqueue_style('opst-css-reset', get_template_directory_uri() . '/css/reset' . OP_SMART_DEBUG . '.css', array(), OP_SMART_THEME_VERSION);
        wp_enqueue_style('opst-css-bootstrap', get_template_directory_uri() . '/css/bootstrap' . OP_SMART_DEBUG . '.css', array('opst-css-reset'), OP_SMART_THEME_VERSION);
        wp_enqueue_style('opst-css-swipebox', get_template_directory_uri() . '/js/swipebox/css/swipebox' . OP_SMART_DEBUG . '.css', array('opst-css-bootstrap'), OP_SMART_THEME_VERSION);
        wp_enqueue_style('opst-css-style', get_template_directory_uri() . '/css/style' . OP_SMART_DEBUG . '.css', array('opst-css-swipebox'), OP_SMART_THEME_VERSION);

    } else {

        wp_enqueue_style('opst-css-style', get_template_directory_uri() . '/css/all' . OP_SMART_DEBUG . '.css', array(), OP_SMART_THEME_VERSION);

    }


    // JS debug version
    if (OP_SMART_DEBUG === '') {

        wp_enqueue_script('opst-js-bootstrap', get_template_directory_uri() . '/js/bootstrap' . OP_SMART_DEBUG . '.js', array('jquery'), OP_SMART_THEME_VERSION, true);
        wp_enqueue_script('opst-js-ie10-viewport-bug-workaround', get_template_directory_uri() . '/js/ie10-viewport-bug-workaround' . OP_SMART_DEBUG . '.js', array('opst-js-bootstrap'), OP_SMART_THEME_VERSION, true);
        wp_enqueue_script('opst-js-fitvids', get_template_directory_uri() . '/js/jquery.fitvids' . OP_SMART_DEBUG . '.js', array('opst-js-ie10-viewport-bug-workaround'), OP_SMART_THEME_VERSION, true);
        wp_enqueue_script('opst-js-swipebox', get_template_directory_uri() . '/js/swipebox/js/jquery.swipebox' . OP_SMART_DEBUG . '.js', array('opst-js-bootstrap'), OP_SMART_THEME_VERSION, true);
        wp_enqueue_script('opst-js-ofi', get_template_directory_uri() . '/js/ofi' . OP_SMART_DEBUG . '.js', array('opst-js-bootstrap'), OP_SMART_THEME_VERSION, true);
        wp_enqueue_script('opst-js-script', get_template_directory_uri() . '/js/script' . OP_SMART_DEBUG . '.js', array('opst-js-fitvids', 'opst-js-ofi'), OP_SMART_THEME_VERSION, true);
        wp_enqueue_script('opst-js-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix' . OP_SMART_DEBUG . '.js', array('opst-js-script'), OP_SMART_THEME_VERSION, true);

    } else {

        wp_enqueue_script('opst-js-script', get_template_directory_uri() . '/js/all' . OP_SMART_DEBUG . '.js', array('jquery'), OP_SMART_THEME_VERSION, true);

    }

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}
add_action('wp_enqueue_scripts', 'op_scripts');

/**
 * Removes the Redux inline styles
 * from LiveEditor pages and
 * from LiveEditor
 */
function remove_output_css($field) {
    if (is_op_page()) {
        return false;
    }
    return $field;
}
add_action('redux/field/op_options/output_css', 'remove_output_css');

/**
 * Add theme support for infinite scroll.
 *
 * @uses add_theme_support
 * @return void
 */
function op_infinite_scroll_init()
{
    global $op_options;

    add_theme_support('infinite-scroll', array(
        'container'         => 'infinite-scroll-container',
        'footer'            => 'colophon',
        'render'            => 'op_infinite_scroll_render',
        'type'              => 'click',
        // 'footer_widgets'    => array(
        //     'op_footer_sidebar_1',
        //     'op_footer_sidebar_2',
        //     'op_footer_sidebar_3',
        //     'op_footer_sidebar_4'
        // ),
        'footer_widgets'    => true,
        'wrapper'           => false,
        'posts_per_page'    => false,
    ));
}
add_action('after_setup_theme', 'op_infinite_scroll_init');

/**
 * Render more posts for infinite scroll.
 * It uses either content-full, content-grid or content-list templates.
 *
 * @return void
 */
function op_infinite_scroll_render()
{
    global $op_options;
    while (have_posts()) : the_post();

        // TODO: Refactor this class handling (related
        // to homepage grid template)
        if (is_home()) {
            if (op_get_homepage_template() === 'grid') {
                echo '<div class="'; op_template_grid_item_class(); echo '">';
            } else {
                echo '<div class="col-md-12">';
            }
            get_template_part('template-parts/loop/content', op_get_homepage_template());
            echo '</div>';
        } else {
            if (op_get_archive_template() === 'grid') {
                echo '<div class="'; op_template_grid_item_class(); echo '">';
            } else {
                echo '<div class="col-md-12">';
            }
            get_template_part('template-parts/loop/content', op_get_archive_template());
            echo '</div>';
        }
    endwhile;
}

/**
 * For the homepage and archives, when grid layout is used, we
 * want to force the number of posts per package (for now)
 * TODO: This can be better. Perhaps an option for this?
 */
function force_posts_per_page($query) {
    global $op_options;

    // This shouldn't affect any admin pages,
    // nor queries other than main query,
    // nor any queries when jetpack
    // infinite scroll is active,
    if (is_admin()
        || !$query->is_main_query()
        || is_infinite_scroll_enabled()
    ) {
        return;
    }

    // Calculate what is the correct number of posts to show in grid layout,
    // based on value set in Setting -> Reading -> Blog pages show at most
    $default_posts_per_page = (int) get_option( 'posts_per_page' );
    $default_mod = $default_posts_per_page % 3;
    $new_posts_per_page = $default_posts_per_page - $default_mod;

    // Homepage
    if (is_home() && op_get_homepage_template() === 'grid') {

        // If homepage hero is off, or hero doesn't contain a post,
        // set the number of posts to new default value,
        // since we don't have to take an
        // additional displayed
        // post into account
        if ((int) $op_options['homepage_hero_enabled'] === 0 || $op_options['homepage_hero_design'] !== 'featured-post') {
            $query->set( 'posts_per_page', $new_posts_per_page );
            return;
        }

        // Homepage Hero is on, so first page must be set to
        // new default value + 1 to account for the
        // featured post, and rest of the pages
        // is set to just new default value
        if (is_paged()) {
            $page_nr = $query->get('paged');
            $offset = (($page_nr - 1) * $new_posts_per_page) + 1;
            $query->set('offset', $offset);
            $query->set('posts_per_page', $new_posts_per_page);
        } else {
            $query->set('posts_per_page', $new_posts_per_page + 1);
        }
    }

    // Archives page
    if (is_archive() && op_get_archive_template() === 'grid') {
        $query->set( 'posts_per_page', $new_posts_per_page );
    }
}
add_action('pre_get_posts', 'force_posts_per_page', 11);

function custom_tag_cloud_widget($args) {
    $args['largest'] = 1; //largest tag
    $args['smallest'] = 1; //smallest tag
    $args['unit'] = 'em'; //tag font unit
    return $args;
}
add_filter('widget_tag_cloud_args', 'custom_tag_cloud_widget');

/**
 * Custom optin style for theme
 */
function custom_optin_style($path, $style, $data){
    if ('optimizetheme_optin_1' == $style) {
        return get_template_directory() . '/inc/optimizetheme_optin_1.php';
    }

    return $path;
}
add_filter('op_style_template_path_optin_form', 'custom_optin_style', 10, 3);

/**
 * Helper functions for this theme.
 */
require get_template_directory() . '/inc/helpers.php';

/**
 * Widgets for this theme.
 */
require get_template_directory() . '/inc/widgets.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Comment Walker.
 */
require get_template_directory() . '/inc/smart_walker_comment.php';

/**
 * Load Share Buttons.
 */
require get_template_directory() . '/inc/share-buttons.php';

/**
 * Load Actions & Filters
 */
require get_template_directory() . '/inc/hooks.php';

/**
 * Load WooCommerce custom parts
 */
require get_template_directory() . '/inc/woocommerce.php';

/**
 * Load auto-updates parts (only if OP is active!)
 */
if (function_exists('op_define_vars')) {
    require get_template_directory() . '/inc/auto-updates.php';
}

add_filter('asp_results', 'asp_filter_invalid_html', 10, 1);
function asp_filter_invalid_html( $results ) {
	foreach ( $results as $k => &$r ) {
		$r->content = strip_tags(html_entity_decode($r->content));
	}           
	return $results;
}
function my_login_logo_one() { 

 ?>
<style type="text/css"> 
body.login div#login h1 a {
 background-image: url(http://amzcrusher.com/wp-content/themes/opSmartTheme/images/logo.png);  //Add your own logo image in this url 
padding-bottom: 30px; 
} 
</style>
 <?php 
} add_action( 'login_enqueue_scripts', 'my_login_logo_one' );
function my_mce_buttons_2( $buttons ) {	
	/**
	 * Add in a core button that's disabled by default
	 */
	$buttons[] = 'superscript';
	$buttons[] = 'subscript';
 
	return $buttons;
}
add_filter( 'mce_buttons_2', 'my_mce_buttons_2' );


add_post_type_support( 'page', 'excerpt' );

/**
* Add theme support for Responsive Videos.
*/
function jetpackme_responsive_videos_setup() {
    add_theme_support( 'jetpack-responsive-videos' );
}
add_action( 'after_setup_theme', 'jetpackme_responsive_videos_setup' );






function wpb_hook_javascript() {
  if (is_page ('10156')) { 

    ?>    <script type="text/javascript">
/* DOM Manipulation
* If you want to update / add single style in DOM Element style attribute you can use this function:
* inject javascript after page reloads.
*/

function setCssStyle(el, style, value) {
  var result = el.style.cssText.match(new RegExp("(?:[;\\s]|^)(" +
      style.replace("-", "\\-") + "\\s*:(.*?)(;|$))")),
    idx;
  if (result) {
    idx = result.index + result[0].indexOf(result[1]);
    el.style.cssText = el.style.cssText.substring(0, idx) +
      style + ": " + value + ";" +
      el.style.cssText.substring(idx + result[1].length);
  } else {
    el.style.cssText += " " + style + ": " + value + ";";
  }
}
var element = document.getElementById("optimizemember-pro-stripe-checkout-form-billing-method-section-title");
setCssStyle(element, "display","none !important");

var element = document.getElementById("optimizemember-pro-stripe-checkout-form-billing-method-section");
setCssStyle(element, "display","none !important");

var element = document.getElementById("optimizemember-pro-stripe-checkout-form-billing-address-section");
setCssStyle(element, "display","none !important");

        </script>
    <?php
  }
}
add_action('wp_head', 'wpb_hook_javascript');





add_action( 'wp_enqueue_scripts', 'custom_contact_script_conditional_loading' );
// load contact form javascript only on contact us page
function custom_contact_script_conditional_loading(){
   //  Edit page IDs here
   if(! is_page('contact-us') )    
   {		
      wp_dequeue_script('contact-form-7'); // Dequeue JS Script file.
      wp_dequeue_style('contact-form-7');  // Dequeue CSS file. 
   }
}


